==> mautrix-0.16.4.tar.gz: mautrix-0.16.4/mautrix/errors/__init__.py <==
from .base import IntentError, MatrixConnectionError, MatrixError, MatrixResponseError
from .crypto import (
    CryptoError,
    DecryptedPayloadError,
    DecryptionError,
    DeviceValidationError,
    DuplicateMessageIndex,
    EncryptionError,
    MatchingSessionDecryptionError,
    MismatchingRoomError,
    SessionNotFound,
    SessionShareError,
    VerificationError,
)
from .request import (
    MatrixBadContent,
    MatrixBadRequest,
    MatrixInvalidToken,
    MatrixRequestError,
    MatrixStandardRequestError,
    MatrixUnknownRequestError,
    MBadJSON,
    MBadState,
    MCaptchaInvalid,
    MCaptchaNeeded,
    MExclusive,
    MForbidden,
    MGuestAccessForbidden,
    MIncompatibleRoomVersion,
    MInvalidParam,
    MInvalidRoomState,
    MInvalidUsername,
    MLimitExceeded,
    MMissingParam,
    MMissingToken,
    MNotFound,
    MNotJSON,
    MRoomInUse,
    MTooLarge,
    MUnauthorized,
    MUnknown,
    MUnknownToken,
    MUnrecognized,
    MUnsupportedRoomVersion,
    MUserDeactivated,
    MUserInUse,
    make_request_error,
    standard_error,
)
from .well_known import (
    WellKnownError,
    WellKnownInvalidVersionsResponse,
    WellKnownMissingHomeserver,
    WellKnownNotJSON,
    WellKnownNotURL,
    WellKnownUnexpectedStatus,
    WellKnownUnsupportedScheme,
)

__all__ = [
    "IntentError",
    "MatrixConnectionError",
    "MatrixError",
    "MatrixResponseError",
    "CryptoError",
    "DecryptedPayloadError",
    "DecryptionError",
    "DeviceValidationError",
    "DuplicateMessageIndex",
    "EncryptionError",
    "MatchingSessionDecryptionError",
    "MismatchingRoomError",
    "SessionNotFound",
    "SessionShareError",
    "VerificationError",
    "MatrixBadContent",
    "MatrixBadRequest",
    "MatrixInvalidToken",
    "MatrixRequestError",
    "MatrixStandardRequestError",
    "MatrixUnknownRequestError",
    "MBadJSON",
    "MBadState",
    "MCaptchaInvalid",
    "MCaptchaNeeded",
    "MExclusive",
    "MForbidden",
    "MGuestAccessForbidden",
    "MIncompatibleRoomVersion",
    "MInvalidParam",
    "MInvalidRoomState",
    "MInvalidUsername",
    "MLimitExceeded",
    "MMissingParam",
    "MMissingToken",
    "MNotFound",
    "MNotJSON",
    "MRoomInUse",
    "MTooLarge",
    "MUnauthorized",
    "MUnknown",
    "MUnknownToken",
    "MUnrecognized",
    "MUnsupportedRoomVersion",
    "MUserDeactivated",
    "MUserInUse",
    "make_request_error",
    "standard_error",
    "WellKnownError",
    "WellKnownInvalidVersionsResponse",
    "WellKnownMissingHomeserver",
    "WellKnownNotJSON",
    "WellKnownNotURL",
    "WellKnownUnexpectedStatus",
    "WellKnownUnsupportedScheme",
]

==> mautrix-0.17.8.tar.gz: mautrix-0.17.8/mautrix/errors/__init__.py <==
from .base import IntentError, MatrixConnectionError, MatrixError, MatrixResponseError
from .crypto import (
    CryptoError,
    DecryptedPayloadError,
    DecryptionError,
    DeviceValidationError,
    DuplicateMessageIndex,
    EncryptionError,
    MatchingSessionDecryptionError,
    MismatchingRoomError,
    SessionNotFound,
    SessionShareError,
    VerificationError,
)
from .request import (
    MAlreadyJoined,
    MatrixBadContent,
    MatrixBadRequest,
    MatrixInvalidToken,
    MatrixRequestError,
    MatrixStandardRequestError,
    MatrixUnknownRequestError,
    MBadJSON,
    MBadState,
    MCaptchaInvalid,
    MCaptchaNeeded,
    MExclusive,
    MForbidden,
    MGuestAccessForbidden,
    MIncompatibleRoomVersion,
    MInsufficientPower,
    MInvalidParam,
    MInvalidRoomState,
    MInvalidUsername,
    MLimitExceeded,
    MMissingParam,
    MMissingToken,
    MNotFound,
    MNotJoined,
    MNotJSON,
    MRoomInUse,
    MTooLarge,
    MUnauthorized,
    MUnknown,
    MUnknownEndpoint,
    MUnknownToken,
    MUnrecognized,
    MUnsupportedRoomVersion,
    MUserDeactivated,
    MUserInUse,
    make_request_error,
    standard_error,
)
from .well_known import (
    WellKnownError,
    WellKnownInvalidVersionsResponse,
    WellKnownMissingHomeserver,
    WellKnownNotJSON,
    WellKnownNotURL,
    WellKnownUnexpectedStatus,
    WellKnownUnsupportedScheme,
)

__all__ = [
    "IntentError",
    "MatrixConnectionError",
    "MatrixError",
    "MatrixResponseError",
    "CryptoError",
    "DecryptedPayloadError",
    "DecryptionError",
    "DeviceValidationError",
    "DuplicateMessageIndex",
    "EncryptionError",
    "MatchingSessionDecryptionError",
    "MismatchingRoomError",
    "SessionNotFound",
    "SessionShareError",
    "VerificationError",
    "MAlreadyJoined",
    "MatrixBadContent",
    "MatrixBadRequest",
    "MatrixInvalidToken",
    "MatrixRequestError",
    "MatrixStandardRequestError",
    "MatrixUnknownRequestError",
    "MBadJSON",
    "MBadState",
    "MCaptchaInvalid",
    "MCaptchaNeeded",
    "MExclusive",
    "MForbidden",
    "MGuestAccessForbidden",
    "MIncompatibleRoomVersion",
    "MInsufficientPower",
    "MInvalidParam",
    "MInvalidRoomState",
    "MInvalidUsername",
    "MLimitExceeded",
    "MMissingParam",
    "MMissingToken",
    "MNotFound",
    "MNotJoined",
    "MNotJSON",
    "MRoomInUse",
    "MTooLarge",
    "MUnauthorized",
    "MUnknown",
    "MUnknownEndpoint",
    "MUnknownToken",
    "MUnrecognized",
    "MUnsupportedRoomVersion",
    "MUserDeactivated",
    "MUserInUse",
    "make_request_error",
    "standard_error",
    "WellKnownError",
    "WellKnownInvalidVersionsResponse",
    "WellKnownMissingHomeserver",
    "WellKnownNotJSON",
    "WellKnownNotURL",
    "WellKnownUnexpectedStatus",
    "WellKnownUnsupportedScheme",
]
